module.exports = defineTest({
	description: 'properly remove coments above import statements'
});
